/*
 * tixUnixInt.h
 *
 *	Internal header file for Tix on the Unix platform.
 *
 * Copyright (c) 1996, Expert Interface Technologies
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef _TIX_UNIX_INT_H_
#define _TIX_UNIX_INT_H_

#ifndef _TIX_INT_H_
#include "tixInt.h"
#endif

#endif /* _TIX_UNIX_INT_H_ */
