MkXSUB("Tk::bind", XS_Tk_bind, XStoBind, Tk_BindCmd)
MkXSUB("Tk::pack", XS_Tk_pack, XStoAfterSub, Tk_PackCmd)
MkXSUB("Tk::grid", XS_Tk_grid, XStoGrid, Tk_GridCmd)
MkXSUB("Tk::place", XS_Tk_place, XStoAfterSub, Tk_PlaceCmd)
MkXSUB("Tk::form", XS_Tk_form, XStoAfterSub, Tix_FormCmd)
MkXSUB("Tk::itemstyle", XS_Tk_itemstyle, XStoTclCmd, Tix_ItemStyleCmd)
MkXSUB("Tk::winfo", XS_Tk_winfo, XStoSubCmd, Tk_WinfoObjCmd)
MkXSUB("Tk::font", XS_Tk_font, XStoFont, Tk_FontObjCmd)
MkXSUB("Tk::wm", XS_Tk_wm, XStoSubCmd, Tk_WmCmd)
MkXSUB("Tk::grab", XS_Tk_grab, XStoSubCmd, Tk_GrabCmd)
MkXSUB("Tk::focus", XS_Tk_focus, XStoSubCmd, Tk_FocusObjCmd)
MkXSUB("Tk::event", XS_Tk_event, XStoEvent, Tk_EventObjCmd)
MkXSUB("Tk::property", XS_Tk_property, XStoSubCmd, Tk_PropertyCmd)
MkXSUB("Tk::clipboard", XS_Tk_clipboard, XStoDisplayof, Tk_ClipboardCmd)
MkXSUB("Tk::bell", XS_Tk_bell, XStoDisplayof, Tk_BellObjCmd)
MkXSUB("Tk::bindtags", XS_Tk_bindtags, XStoTk, Tk_BindtagsCmd)
MkXSUB("Tk::destroy", XS_Tk_destroy, XStoTk, Tk_DestroyCmd)
MkXSUB("Tk::raise", XS_Tk_raise, XStoTk, Tk_RaiseCmd)
MkXSUB("Tk::lower", XS_Tk_lower, XStoTk, Tk_LowerCmd)
MkXSUB("Tk::option", XS_Tk_option, XStoOption, Tk_OptionCmd)
MkXSUB("Tk::image", XS_Tk_image, XStoImage, Tk_ImageObjCmd)
MkXSUB("Tk::selection", XS_Tk_selection, XStoTk, Tk_SelectionCmd)

MkXSUB("Tk::tk_chooseColor", XS_Tk_tk_chooseColor, XStoTk, Tk_ChooseColorCmd)
MkXSUB("Tk::tk_getOpenFile", XS_Tk_tk_getOpenFile, XStoTk, Tk_GetOpenFileCmd)
MkXSUB("Tk::tk_getSaveFile", XS_Tk_tk_getSaveFile, XStoTk, Tk_GetSaveFileCmd)
MkXSUB("Tk::tk_messageBox", XS_Tk_tk_messageBox, XStoTk, Tk_MessageBoxCmd)
MkXSUB("Tk::tk", XS_Tk_tk, XStoTclCmd, Tk_TkObjCmd)

#if 0
MkXSUB("Tk::exit", XS_Tk_exit, XStoNoWindow, Tcl_ExitCmd)
MkXSUB("Tk::fileevent", XS_Tk_fileevent, XStoNoWindow, Tcl_FileeventCmd)
#endif
MkXSUB("Tk::after", XS_Tk_after, XStoNoWindow, Tcl_AfterObjCmd)
#ifndef WIN32
MkXSUB("Tk::send", XS_Tk_send, XStoTclCmd, Tk_SendCmd)
#endif
MkXSUB("Tk::button", XS_Tk_button, XStoTclCmd, Tk_ButtonCmd)
MkXSUB("Tk::checkbutton", XS_Tk_checkbutton, XStoTclCmd, Tk_CheckbuttonCmd)
MkXSUB("Tk::label", XS_Tk_label, XStoTclCmd, Tk_LabelCmd)
MkXSUB("Tk::message", XS_Tk_message, XStoTclCmd, Tk_MessageCmd)
MkXSUB("Tk::_menu", XS_Tk__menu, XStoTclCmd, Tk_MenuCmd)
MkXSUB("Tk::radiobutton", XS_Tk_radiobutton, XStoTclCmd, Tk_RadiobuttonCmd)
MkXSUB("Tk::frame", XS_Tk_frame, XStoTclCmd, Tk_FrameCmd)
MkXSUB("Tk::toplevel", XS_Tk_toplevel, XStoTclCmd, Tk_ToplevelCmd)
MkXSUB("Tk::update", XS_Tk_update, XStoTclCmd, Tk_UpdateCmd)
MkXSUB("Tk::tkwait", XS_Tk_tkwait, XStoTclCmd, Tk_TkwaitCmd)
MkXSUB("Tk::configure", XS_Tk_configure, XStoWidget, newSVpv("configure",0))
MkXSUB("Tk::cget", XS_Tk_cget, XStoWidget, newSVpv("cget",0))

